#
# spec file for package stgit
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           stgit
Version:        0.23
Release:        bp154.1.34
Summary:        Stacked GIT - Source Code Management Tool
License:        GPL-2.0-or-later
Group:          Development/Tools/Version Control
URL:            https://stacked-git.github.io
Source0:        https://github.com/ctmarinas/stgit/releases/download/v%{version}/stgit-%{version}.tar.gz
# Patch sent upstream, PR 81: https://github.com/stacked-git/stgit/pull/81
Patch1:         stgbashprompt-noexec.patch
BuildRequires:  asciidoc
BuildRequires:  fdupes
BuildRequires:  git-core
BuildRequires:  python-rpm-macros
BuildRequires:  python3-setuptools
BuildRequires:  xmlto
Requires:       git-core
BuildArch:      noarch

%description
StGIT is a Python application providing similar functionality to Quilt
(i.e. pushing/popping patches to/from a stack) on top of GIT. These
operations are performed using GIT commands and the patches are stored
as GIT commit objects, allowing easy merging of the StGIT patches into
other repositories using standard GIT functionality.

%prep
%setup -q
%patch1 -p1

%build
%python3_build
PYTHON=python3 make %{?_smp_mflags} prefix=%{_prefix} doc

%install
%python3_install
PYTHON=python3 make %{?_smp_mflags} prefix=%{_prefix} mandir=%{_mandir} DESTDIR=%{buildroot} install-doc
# avoid unreproducible pyc files https://bugs.python.org/issue34033 https://github.com/python/cpython/pull/8057
%py3_compile %{buildroot}%{python3_sitelib}
%fdupes %{buildroot}%{python3_sitelib}

%files
%license COPYING
%doc CONTRIBUTING.md CHANGELOG.md TODO
%{_bindir}/stg
%{_mandir}/man1/stg*%{ext_man}
%{python3_sitelib}/*
%{_datadir}/stgit

%changelog
* Tue Nov 10 2020 Dario Faggioli <dfaggioli@suse.com>
- Move to latest version, 0.23
  * `stg mail` was not working in v. 0.21, due to TLS issue. It
    does in 0.23
  * while there, update the URL
- Add patch stgbashprompt-noexec.patch
  * so rpmlint won't complain about executable without '#!'
* Fri Jan 17 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Create .pyc files reproducibly (boo#1049186)
* Mon Jan 13 2020 tiwai@suse.de
- Revive asciidoc; will be replaced or dropped later, depending on
  the general solution of asciidoc support on TW
* Mon Jan 13 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.21:
  * Build reproducibility repairs (Thanks reproducible-builds.org team!)
  * Faster handling of large patches (#44)
  * Python can now be run with optimizations (python -O)
  * stg log now prints trailing newline
  * Improved command line option parsing for stg log
* Mon Jan 13 2020 Tomáš Chvátal <tchvatal@suse.com>
- Switch to python3 to build
- Disable documentation generating using asciidoc as that requires
  python2
* Thu Aug  8 2019 Mikhail Terekhov <termim@gmail.com>
- updated to version 0.19
  - - Python 3 support. StGit supports Python 2.6, 2.7, 3.3, 3.4, 3.5, 3.6,
    and 3.7. PyPy interpreters are also supported.
  - - Submodules are now ignored when checking if working tree is
    clean. Submodules are also not included by default when refreshing a
    patch.
  - - Config booleans are now parsed similarly to git-config.
  - - contrib/stgit.el is now licenced with GPLv2.
  - - Repair handling of emails with utf-8 bodies containing latin-1
    characters. Also correctly decode email headers containing quoted encoded
    words.
  - - StGit's version is now correct/available the release archive.
  - - Add continuous integration (travis-ci) and code coverage (coveralls) support.
  - - Many new test cases were added.
- updated to version 0.18
  - - commit-msg hook support for easier integration with Gerrit, allowing a
    Change-Id line to be inserted in the commit message.
  - - stg mail improvements for Suggested-by: tag and auto generation of Cc
    for the cover letter based on all tags in the series.
  - - stg mail bash completion for the -to, -cc and -bcc options based on
    the content of the [mail "alias"] section of GIT configuration.
  - - stg edit -review option to add a Reviewed-by: tag.
  - - stg pop -spill functionality to allow popping a patch from the stack
    while keeping its modification in the tree.
  - - Various fixes and test coverage improvements.
  - - Project page details updated (gna.org has been shut down).
* Wed Mar 30 2016 mpluskal@suse.com
- Use url for source
- Add gpg signature
- Cleanup spec file with spec-cleaner
* Wed Oct  2 2013 david.bahi@emc.com
- updated to version 0.17.1
  - - Fix dirty index errors when resolving conflicts.
  - - Test suite improvements.
  - - Print tracebacks to stderr.
  - - Run test suite in parallel.
  - - Fix --authdate date parsing.
- changes from version 0.16 to 0.17
  - - Make refresh warn when the index is dirty
  - - Template updates to not hardcode whitespace
  - - Properly generate mbox formats when attaching patches
  - - Added new option to attach and inline patches when sending mail
  - - Various bugfixes and tiny improvements
* Tue Feb 28 2012 tiwai@suse.de
- updated to version 0.16:
  * Several improvements to the Emacs mode (stgit.el).
  * UI adjustments to better match the Git commands.
  * "stg status" is an alias for "git status".
  * "stg reset --hard" behaves similarly to the corresponding git
    command and option.
  * "stg branch --cleanup" option to remove the StGit metadata for
    a given branch.
  * "stg mail" can use "git send-email" directly.
  * Vim syntax highlighting for StGit commit messages.
  * Many bug-fixes.
* Mon Aug 10 2009 tiwai@suse.de
- fix build with older distros
- build as noarch for Factory
* Sun Aug  9 2009 coolo@novell.com
- use new python macros
* Tue Jun 10 2008 tiwai@suse.de
- updated to version 0.14.3:
  a maintenance release including bug-fixes for the "refresh"
  command, handling of file names with non-ASCII characters and
  user interface enhancements for "export" and "sync"
* Mon Apr 14 2008 tiwai@suse.de
- updated to version 0.14.2:
  * a maintenance release including bug-fixes and a few user
    interface enhancements
* Fri Jan 11 2008 tiwai@suse.de
- updated to version 0.14.1:
  * Fixed typo in the required version of Python
- updated to version 0.14:
  * Support for correctly running StGIT in subdirectories
  * 'repair' command for fixing an StGIT repository modified by
    GIT commands such as 'commit', 'pull', 'merge' or 'rebase'
  * 'edit' command for editing both the patch description and diff
  * Support for SMTP over TLS
  * Support for MIME multipart e-mail templates
  * '--attach' option to the 'mail' command to send a patch
    attached rather than inline
  * Diff statistics and shortlog added to the cover e-mail
    template
  * '--sign/ack' options to the 'import' and 'new' commands
  * '--number' to the 'log' command for limiting the output
  * Support for binary files in patches
  * Support for detached HEAD
  * Refactoring of some modules with better support for debugging
  * Many bug-fixes
* Thu Jul 26 2007 tiwai@suse.de
- updated to version 0.13:
  * Documentation directory with man pages
  * Safety checks for the 'rebase' command
  * Various contrib scripts
  * 'cp' command to copy files
  * 'sink' command to complement 'float'
  * '--diff-opts' option to some commands for passing
    additional arguments to 'git-diff-*'
  * 'stgit.mail.prefix' configuration option for the default
    'mail --prefix' value
  * Interractive 2-way merging via xxdiff or emacs (previously,
    only 3-way merging had this feature)
  * Slightly changed behaviour to the 'patches' command when no
    argument is given to show the patches touching the locally
    modified files
  * Correct importing of multipart e-mails
  * '--unrelated' option to 'mail' to send patches unthreaded
    and without sequence numbering
  * '--update' option to 'refresh' to only check in the files
    already modified by the current patch (similar to
    'pick --update')
  * '--keep' option to 'goto' (though it only works for patch
    popping)
  * '--expose' option to 'pick' to append the picked commit id
    to the log (similar to the 'git cherry-pick -x' command)
  * The 'new' command can automatically generate the patch name'
    from the given log
  * 'uncommit' can generate patches up to a given commit id
  * Bug fixes
* Mon Apr  2 2007 tiwai@suse.de
- updated to verison 0.12.1:
  * Allow StGIT to run when there is no user information
    configured
  * Use 'git-pull' rather than 'git-fetch' by default
  * Fix the 'mail' command to parse multiple-lines address
    headers
  * Fix the alias check in the 'stg mail --bcc' command
  * Add '--merged' option to rebase
  * Add '--url' option to 'import' to import a file directly
    from the network
  * Add '--author' option to 'series'
* Wed Feb  7 2007 tiwai@suse.de
- updated to version 0.12:
  * New 'rebase' command to change the base of an StGIT stack
  * New 'hide' and 'unhide' commands to act on the patches in a
    series.
  * New 'sync' command to synchronise same patches in different
    branches
  * New 'assimilate' command to transform GIT (accidental)
    commits at the top of the stack in StGIT patches
  * Re-worked pulling logic to use the branch information stored
    in the .git/config file
  * Abbreviation for StGIT commands
  * Correct encoding of the e-mail headers and body
  * Support for importing multipart e-mails and mbox files
  * Configuration read from the GIT config files rather than
    stgitrc
  * Patch ranges can be specified for 'export'
  * '--missing' option for 'series' to list the patches on a
    branch which are missing in current
  * StGIT bash completion script
  * Bug fixes
* Tue Jan  9 2007 tiwai@suse.de
- updated to version 0.11:
  * new 'float' command
  * patch history support, accessible through log command
  * automatically generate patch names
  * many new options, bug fixes
* Wed Sep 20 2006 tiwai@suse.de
- initial version: 0.10
